Monoids
=======

Sage supports free monoids and free abelian monoids in any
finite number of indeterminates, as well as free partially
commutative monoids (trace monoids).

.. toctree::
   :maxdepth: 1

   sage/monoids/monoid
   sage/monoids/free_monoid
   sage/monoids/free_monoid_element
   sage/monoids/free_abelian_monoid
   sage/monoids/free_abelian_monoid_element
   sage/monoids/indexed_free_monoid
   sage/monoids/string_monoid
   sage/monoids/string_monoid_element
   sage/monoids/string_ops
   sage/monoids/hecke_monoid
   sage/monoids/automatic_semigroup
   sage/monoids/trace_monoid

.. include:: ../footer.txt
